@@ -111,8 +111,9 @@ data FencedHandler = FHRaw (Text -> [Block Text])
                    | FHParsed ([Block Text] -> [Block Text])
                      -- ^ Wrap up the given parsed content.
 
-instance Default MarkdownSettings where
-    def = MarkdownSettings
+-- | @since 0.1.15
+defaultMarkdownSettings :: MarkdownSettings
+defaultMarkdownSettings = MarkdownSettings
         { msXssProtect = True
         , msStandaloneHtml = empty
         , msFencedHandlers = codeFencedHandler "```" `mappend` codeFencedHandler "~~~"
@@ -126,6 +127,9 @@ instance Default MarkdownSettings where
         , msAddHeadingId = False
         }
 
+instance Default MarkdownSettings where
+    def = defaultMarkdownSettings
+
 -- | Helper for creating a 'FHRaw'.
 --
 -- Since 0.1.2
